function MYOEx85Alt
% MYOEx85Alt  Head loss problem of Example 8.5 in Munson, Young and Okiishi
%             Use the pipeLoss function to compute head loss

% --- Define constants for the system and its components
L = 0.1;          %  Pipe length (m)
D = 4e-3;         %  Pipe diameter (m)
A = 0.25*pi*D.^2; %  Cross sectional area
e = 0.0015e-3;    %  Roughness for drawn tubing
rho = 1.23;       %  Density of air (kg/m^3) at 20 degrees C
mu = 1.79e-5;     %  Dynamic viscosity (kg/m/s) at 20 degrees C
nu = mu/rho;      %  Kinematic viscosity (m^2/s)
V = 50;           %  Air velocity (m/s)

% --- The pipeLoss function uses root-finding to find head loss at given Q 
[hv,f] = pipeLoss(V*A,L,A,D,e,nu);
Re = V*D/nu;
flam = 64/Re;
dplam = flam * 0.5*(L/D)*rho*V^2;
dp = rho*9.81*hv;

% --- Print summary of losses
fprintf('\nMYO Example 8.5:  Re = %12.3e\n\n',Re);
fprintf('\tLaminar flow:   ');
fprintf('flam = %8.5f;   Dp = %8.0f (Pa)\n',flam,dplam)
fprintf('\tTurbulent flow: ');
fprintf('f    = %8.5f;   Dp = %8.0f (Pa)\n',f,dp);